===============================
pyeasyga
===============================

.. image:: https://badge.fury.io/py/pyeasyga.png
    :target: http://badge.fury.io/py/pyeasyga

.. image:: https://travis-ci.org/remiomosowon/pyeasyga.png?branch=develop
    :target: https://travis-ci.org/remiomosowon/pyeasyga

.. image:: https://coveralls.io/repos/remiomosowon/pyeasyga/badge.png?branch=develop
    :target: https://coveralls.io/r/remiomosowon/pyeasyga?branch=develop

.. image:: https://pypip.in/d/pyeasyga/badge.png
    :target: https://pypi.python.org/pypi/pyeasyga

-------------------------------------------------------------------

A simple and easy-to-use Genetic Algorithm implementation library in Python.

``pyeasyga`` provides a simple interface to the power of Genetic Algorithms
(GAs). You don't have to have expert GA knowledge in order to use it.

* Free software: BSD license
* Documentation: http://pyeasyga.readthedocs.org.

.. include:: ../examples/README.rst

Note
--------

* Currently under development
